<template>
	<el-tabs v-model="activeName" class="demo-tabs min-w-[38rem] flex-column">
		<el-tab-pane class="h-full" label="Chart" name="first">
			<div class="flex-auto" v-resize="chartContainerResize">
				<div ref="chartRef" class="h-full"></div>
			</div>
		</el-tab-pane>
		<el-tab-pane class="h-full" label="Data" name="second">
			<el-table :data="data.values" style="width: 100%" cellClassName="" headerCellClassName="">
				<el-table-column v-for="(item, index) in data?.names" :label="item" :key="index">
					<template #default="scope">
						{{ scope.row[index] }}
					</template>
				</el-table-column>
			</el-table>
		</el-tab-pane>
	</el-tabs>
</template>
<script lang="ts" setup>
import type * as echarts from 'echarts';
import { defaultsDeep } from 'lodash-es';
import { ref } from 'vue';
import { SCATTER_SYMBOL_SIZE, chatComProps, getChatChartOption } from '../common';
import { useDrawChatChart } from '../hooks/useDrawChatChart';
const activeName = ref('first');
const chartRef = ref<HTMLDivElement>(null);

const defaultChartType = 'line';
const props = defineProps(chatComProps);

const drawChart = () => {
	chartInstance.value.setOption(
		defaultsDeep(getChatChartOption(), {
			grid: {
				bottom: '5%',
			},

			toolbox: {
				feature: {
					myBar: {
						onclick: () => {
							chartInstance.value.setOption({
								series: {
									data: props.data.values,
									type: 'bar',
									symbol: 'none',
								},
							});
						},
					},

					myScatter: {
						onclick: () => {
							chartInstance.value.setOption({
								data: props.data.values,
								type: 'scatter',
								symbol: 'circle',
								symbolSize: SCATTER_SYMBOL_SIZE,
							});
						},
					},
					myLine: {
						onclick: () => {
							chartInstance.value.setOption({
								data: props.data.values,
								type: 'line',
								symbol: 'none',
								smooth: true,
							});
						},
					},
				},
			},

			title: {
				text: props.data.title,
			},
			xAxis: {
				name: props.data?.names[0],
			},
			yAxis: {
				name: props.data?.names[1],
			},
			series: [
				{
					data: props.data.values,
					symbol: 'none',
					smooth: true,
					type: defaultChartType,
				},
			],
		} as echarts.EChartsOption)
	);
};
const { chartContainerResize, chartInstance } = useDrawChatChart({ chartRef, drawChart });
</script>

<style scoped lang="scss">
.el-tabs {
	:deep(.el-tabs__header) {
		flex: 0 0 auto;
	}
	:deep(.el-tabs__content) {
		flex: 1;
		.el-tab-pane {
			display: flex;
			flex-direction: column;
			min-height: 24rem;
		}
	}
}
</style>
